@@ -8,7 +8,7 @@ use MooseX::InsideOut;
 use Carp;
 use English qw{-no_match_vars};
 
-with qw{MooseX::AttributeCloner};
+with qw{MooseX::Getopt MooseX::AttributeCloner};
 
 has q{attr1} => (isa => q{Str}, is => q{ro}, predicate => q{has_attr1});
 has q{attr2} => (isa => q{Str}, is => q{ro}, required => 1);
@@ -21,7 +21,7 @@ has q{attr7} => (isa => q{Str}, is => q{ro});
 has q{object_attr} => (isa => q{Object}, is => q{ro});
 has q{hash_attr} => (isa => q{HashRef}, is => q{ro});
 has q{array_attr} => (isa => q{ArrayRef}, is => q{ro});
-
+has q{Boolean} => (isa => q{Bool}, is => q{rw});
 no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
